@@ -49,7 +49,8 @@ my $configure_fullautoapi=sub {
    my $selection=$_[0]||'';
    my ($stdout,$stderr)=('','');
    my $handle=$localhost;my $connect_error='';
-   $localhost->cwd('~');
+   $handle->cwd('~');
+   my $userhome=$handle->cmd('pwd');
    my $sudo=($^O eq 'cygwin')?'':'sudo ';
 $do=1;
 if ($do==1) {
@@ -204,6 +205,8 @@ if ($do==1) {
          'pkgconfig libtool gcc-c++','__display__');
    }
    ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/deps",'__display__');
+   ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/root/static/images",
+      '__display__');
    ($stdout,$stderr)=$handle->cwd("FullAutoAPI/deps");
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".
@@ -564,7 +567,9 @@ END
          cmd_raw($handle,
             "${sudo}LD_LIBRARY_PATH=/usr/local/lib ".
             "PKG_CONFIG_PATH=/usr/local/lib/pkgconfig ".
-            "LD_PRELOAD=/usr/local/lib/libzmq.so.5 cpan -f -i $module",
+            "LD_PRELOAD=/usr/local/lib/libzmq.so.5 ".
+            "LOCAL_FULLAUTOAPI_PATH=$userhome/FullAutoAPI ".
+            "cpan -f -i $module",
             '__display__');
       } else {
          cmd_raw($handle,"cpan -i $module",
@@ -980,36 +985,36 @@ END
        "    +CatalystX::SimpleLogin";
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i '/    Static::Simple/a$ad' $pm_path");
-   $ad="   authentication => {%NL%".
-       "      default_realm => %SQ%users%SQ%,%NL%".
-       "      realms        => {%NL%".
-       "         users => {%NL%".
-       "            credential => {%NL%".
-       "               class          => %SQ%Password%SQ%,%NL%".
-       "               password_field => %SQ%password%SQ%,%NL%".
-       "               password_type  => %SQ%self_check%SQ%%NL%".
-       "            },%NL%".
-       "            store => {%NL%".
-       "               class         => %SQ%DBIx::Class%SQ%,%NL%".
-       "               user_model    => %SQ%DB::Users%SQ%,%NL%".
-       "               role_relation => %SQ%roles%SQ%,%NL%".
-       "               role_field    => %SQ%name%SQ%,%NL%".
-       "            }%NL%".
-       "         }%NL%".
-       "      },%NL%".
-       "   },%NL%".
-       "   %SQ%Controller::Login%SQ% => {%NL%".
-       "       traits => [%SQ%-RenderAsTTTemplate%SQ%],%NL%".
-       "       login_form_args => {%NL%".
-       "           authenticate_args => { active => %SQ%Y%SQ% },%NL%".
+   $ad="    authentication => {%NL%".
+       "       default_realm => %SQ%users%SQ%,%NL%".
+       "       realms        => {%NL%".
+       "          users => {%NL%".
+       "             credential => {%NL%".
+       "                class          => %SQ%Password%SQ%,%NL%".
+       "                password_field => %SQ%password%SQ%,%NL%".
+       "                password_type  => %SQ%self_check%SQ%%NL%".
+       "             },%NL%".
+       "             store => {%NL%".
+       "                class         => %SQ%DBIx::Class%SQ%,%NL%".
+       "                user_model    => %SQ%DB::Users%SQ%,%NL%".
+       "                role_relation => %SQ%roles%SQ%,%NL%".
+       "                role_field    => %SQ%name%SQ%,%NL%".
+       "             }%NL%".
+       "          }%NL%".
        "       },%NL%".
-       "   },";
+       "    },%NL%".
+       "    %SQ%Controller::Login%SQ% => {%NL%".
+       "        traits => [%SQ%-RenderAsTTTemplate%SQ%],%NL%".
+       "        login_form_args => {%NL%".
+       "            authenticate_args => { active => %SQ%Y%SQ% },%NL%".
+       "        },%NL%".
+       "    },";
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i '/Send X-Catalyst header/a$ad' $pm_path");
    ($stdout,$stderr)=$handle->cmd(
-       "${sudo}sed -i 's/\\(^Session$\\\)/    \\1/' $pm_path");
+       "${sudo}sed -i 's/\\\\(^Session$\\\\\)/    \\\\1/' $pm_path");
    ($stdout,$stderr)=$handle->cmd(
-       "${sudo}sed -i 's/\\(^authentication =.*\\\)/    \\1/' $pm_path");
+       "${sudo}sed -i 's/\\\\(^authentication =.*\\\\\)/    \\\\1/' $pm_path");
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" $pm_path");
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" $pm_path");
@@ -1624,7 +1629,7 @@ END
        "%NL%".
        "use Parallel::Forker;%NL%".
        "%NL%".
-       "system(\"/usr/local/bin/memcached &\");%NL%".
+       "system(\"nohup /usr/local/bin/memcached >> /dev/null 2>&1 &\");%NL%".
        "%NL%".
        "my \$fa_sub=sub {%NL%".
        "%NL%".
